/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package de.hillenbrand.dupfinder;

import java.io.*;
import java.util.*;
import java.text.*;

class JDupFinderFile implements Comparable {
	private static final boolean DEBUG = false;

	final static Collator collator = Collator.getInstance();
	
	String filename = null;
	long length = 0;
	
	public JDupFinderFile(String filename)  {
		this.filename = filename;
		
		File file = new File(filename);
		this.length = file.length();
	}

	public static final boolean areDifferent(JDupFinderFile f1, JDupFinderFile f2)  {
		if (f1.length != f2.length) return true;
		if (f1.length == 0) return true;
		
		final byte [] buffer1 = new byte[1024];
		final byte [] buffer2 = new byte[1024];
		
		try
			{
			final FileInputStream in1 = new FileInputStream(f1.filename);
			final FileInputStream in2 = new FileInputStream(f2.filename);
			
			int read1=-1, read2=-1;
			
			do 
				{
				read1 = in1.read(buffer1);
				read2 = in2.read(buffer2);
			
				if (read1 != read2) System.err.println("This should not happen: read different amount of data from disk");
			
				for (int i=0; i<read1; ++i)
					{
					if (buffer1[i] == buffer2[i]) continue;
					in2.close();
					in1.close();
					return true;
					}
				}
			while (read1 != -1);
			
			in2.close();
			in1.close();
			}
		catch (IOException x) { System.err.println("JDupFinderFile.areDifferent(): " + x); return true; }
		
		return false;
	}

	public int compareTo(Object other)  {
		JDupFinderFile otherFile = (JDupFinderFile) other;
		
		if (this.length < otherFile.length) return -1;
		else if (this.length > otherFile.length) return 1;
		else return collator.compare(filename, otherFile.filename);
	}

	public String toString()  {
		return filename+" ["+length+" byte]";
	}

}
